@@ -39,21 +39,6 @@ while read i; do
 	systemctl enable $i
 done < /etc/os-installer/bits/systemd.services
 
-# Make GDM start gnome-initial-setup on first boot
-sudo cp -v /etc/os-installer/bits/gdm/custom.conf $R/etc/gdm/custom.conf
-sudo chroot "/mnt/root" /usr/bin/env -i	\
-	HOME=/root                  	\
-	TERM="$TERM"                	\
-	PS1='(yiffOS chroot) \u:\w\$ ' 	\
-	PATH=/usr/bin:/usr/sbin     	\
-	chown gdm:gdm /etc/gdm/custom.conf
-
-# This will be changed by the GNOME setup
-echo "LANG=en_US.UTF-8" | sudo tee $R/etc/locale.conf
-
-# Set hostname
-echo "yiffos" | sudo tee $R/etc/hostname
-
 # Generate users
 sudo chroot "/mnt/root" /usr/bin/env -i	\
 	HOME=/root                  	\
@@ -62,15 +47,40 @@ sudo chroot "/mnt/root" /usr/bin/env -i	\
 	PATH=/usr/bin:/usr/sbin     	\
 	systemd-sysusers
 
-# Run GNOME postinsts
+# Make GDM start gnome-initial-setup on first boot
+#sudo cp -v /etc/os-installer/bits/gdm/custom.conf $R/etc/gdm/custom.conf
+#sudo chroot "/mnt/root" /usr/bin/env -i	\
+#	HOME=/root                  	\
+#	TERM="$TERM"                	\
+#	PS1='(yiffOS chroot) \u:\w\$ ' 	\
+#	PATH=/usr/bin:/usr/sbin     	\
+#	chown gdm:gdm /etc/gdm/custom.conf
 
-echo "#!/bin/bash" 					| sudo tee -a $R/gnomepostinst.sh
-echo "glib-compile-schemas /usr/share/glib-2.0/schemas" | sudo tee -a $R/gnomepostinst.sh
-echo "gdk-pixbuf-query-loaders --update-cache" 		| sudo tee -a $R/gnomepostinst.sh
-echo "for f in /usr/share/icons/*/; do" 		| sudo tee -a $R/gnomepostinst.sh
-echo "gtk4-update-icon-cache -t -f $f" 			| sudo tee -a $R/gnomepostinst.sh
-echo "gtk-update-icon-cache -t -f $f" 			| sudo tee -a $R/gnomepostinst.sh
-echo "done" 						| sudo tee -a $R/gnomepostinst.sh
+# This will be changed by the GNOME setup
+echo "LANG=en_US.UTF-8" | sudo tee $R/etc/locale.conf
+
+# Set hostname
+echo "yiffOS" | sudo tee $R/etc/hostname
+
+# Make user
+sudo chroot "/mnt/root" /usr/bin/env -i	\
+	HOME=/root                  	\
+	TERM="$TERM"                	\
+	PS1='(yiffOS chroot) \u:\w\$ ' 	\
+	PATH=/usr/bin:/usr/sbin     	\
+	useradd -mG wheel ${OSI_USER_NAME}
+
+# Run GNOME postinsts
+echo "#!/bin/bash" 							| sudo tee -a $R/gnomepostinst.sh
+echo "echo ${OSI_USER_PASSWORD} | passwd --stdin ${OSI_USER_NAME}" 	| sudo tee -a $R/gnomepostinst.sh
+echo "glib-compile-schemas /usr/share/glib-2.0/schemas" 		| sudo tee -a $R/gnomepostinst.sh
+echo "update-mime-database /usr/share/mime/" 				| sudo tee -a $R/gnomepostinst.sh
+echo "gtk-query-immodules-3.0 --update-cache" 				| sudo tee -a $R/gnomepostinst.sh
+echo "gdk-pixbuf-query-loaders --update-cache" 				| sudo tee -a $R/gnomepostinst.sh
+echo "for f in /usr/share/icons/**/; do" 				| sudo tee -a $R/gnomepostinst.sh
+echo "gtk4-update-icon-cache -t -f \$f" 				| sudo tee -a $R/gnomepostinst.sh
+echo "gtk-update-icon-cache -t -f \$f" 					| sudo tee -a $R/gnomepostinst.sh
+echo "done" 								| sudo tee -a $R/gnomepostinst.sh
 
 sudo chmod +x $R/gnomepostinst.sh
 
